@@ -2,11 +2,12 @@ use crate::types::ProcessInfo;
 use crate::Pid;
 use clap::{ArgEnum, Parser};
 use precord_core::System;
+use std::collections::HashSet;
 use std::path::PathBuf;
 use sysinfo::{ProcessExt, ProcessStatus, SystemExt};
 
 #[derive(Parser, Debug, Clone)]
-#[clap(version = "0.4.6")]
+#[clap(version = "0.4.9")]
 #[clap(about = "A command line tool to record process and system performance data.")]
 pub struct Opts {
     #[clap(short, long, multiple_values = true)]
@@ -84,11 +85,19 @@ impl Opts {
             }
 
             if let Some(sysinfo_system) = system.sysinfo_system() {
+                let mut visited = HashSet::new();
+                visited.insert(parent);
+
                 while let Some(parent_process) = sysinfo_system.process(parent) {
                     if let Some(parent2) = parent_process.parent() {
+                        if visited.contains(&parent2) {
+                            return false;
+                        }
+
                         if processes.iter().position(|p| p.pid == parent2).is_some() {
                             return true;
                         }
+                        visited.insert(parent2);
                         parent = parent2;
                     } else {
                         return false;
@@ -129,6 +138,10 @@ pub enum Category {
     Mem,
     GPU,
     FPS,
+    #[clap(name = "net_in")]
+    NetIn,
+    #[clap(name = "net_out")]
+    NetOut,
     #[clap(name = "sys_cpu_freq")]
     SysCPUFreq,
     #[clap(name = "sys_cpu_temp")]
@@ -143,6 +156,8 @@ pub enum ProcessCategory {
     Mem,
     GPU,
     FPS,
+    NetIn,
+    NetOut,
 }
 
 #[derive(Copy, Clone, PartialEq)]
